pub struct EnrichedEvent {
pub registration_id: RegistrationId,
pub speaker_ip: IpAddr,
pub service: Service,
pub event_source: EventSource,
pub timestamp: SystemTime,
pub event_data: EventData,
}Expand description
An enriched event that includes context and source information
Fields
registration_id: RegistrationIdRegistration ID this event belongs to
speaker_ip: IpAddrIP address of the speaker that generated this event
service: ServiceUPnP service that generated this event
event_source: EventSourceSource of this event (UPnP notification or polling)
timestamp: SystemTimeTimestamp when this event was processed
event_data: EventDataThe actual event data
Implementations
Sourceimpl EnrichedEvent
impl EnrichedEvent
Sourcepub fn new(
registration_id: RegistrationId,
speaker_ip: IpAddr,
service: Service,
event_source: EventSource,
event_data: EventData,
) -> Self
pub fn new( registration_id: RegistrationId, speaker_ip: IpAddr, service: Service, event_source: EventSource, event_data: EventData, ) -> Self
Create a new enriched event